==> ogre-docs-1.11.5-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_depth_buffer.js <==
var class_ogre_1_1_depth_buffer =
[
    [ "PoolId", "group___render_system.html#ga9854c57374adef41216bae68544a5b7e", [
      [ "POOL_NO_DEPTH", "group___render_system.html#gga9854c57374adef41216bae68544a5b7ea569228ed0fdd8d428a5117026b6d010e", null ],
      [ "POOL_MANUAL_USAGE", "group___render_system.html#gga9854c57374adef41216bae68544a5b7ea2d5409ddce167e1db415f09ee2160440", null ],
      [ "POOL_DEFAULT", "group___render_system.html#gga9854c57374adef41216bae68544a5b7ea00a687046bfe7a9ebd7f34256d3fbcca", null ]
    ] ],
    [ "DepthBuffer", "group___render_system.html#ga90ab98914c730458fccb9780f850b905", null ],
    [ "~DepthBuffer", "group___render_system.html#ga23ee0fd93e778767b81bebd382bb4306", null ],
    [ "_setPoolId", "group___render_system.html#ga7af5c611687492846891914dcac303d2", null ],
    [ "getPoolId", "group___render_system.html#ga82b30e2ad5de1ac4678fda52ccbaf28f", null ],
    [ "getBitDepth", "group___render_system.html#ga0da54b20b25ac5313fc8c142e8b35168", null ],
    [ "getWidth", "group___render_system.html#gae5095fe367bf95d08dee2da03810beb2", null ],
    [ "getHeight", "group___render_system.html#gaf95e6998e74db40257cb2ca5cab4bdf4", null ],
    [ "getFsaa", "group___render_system.html#gafb31d279263557b92843f6715ba6e8c2", null ],
    [ "getFsaaHint", "group___render_system.html#ga2d44455830254b7da1058ad542f9a439", null ],
    [ "isManual", "group___render_system.html#ga4a3de78684016598642ad2d00e5caa86", null ],
    [ "isCompatible", "group___render_system.html#gae959f6dd77e0e8b6aa9b7c6a3d2d3f5d", null ],
    [ "_notifyRenderTargetAttached", "group___render_system.html#ga26c4ce1003ddab1ed7e3befecb0888a1", null ],
    [ "_notifyRenderTargetDetached", "group___render_system.html#ga227b541ef2ae3de53334c10397a08f99", null ]
];

==> ogre-docs-1.12.0-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/class_ogre_1_1_depth_buffer.js <==
var class_ogre_1_1_depth_buffer =
[
    [ "PoolId", "group___render_system.html#ga9854c57374adef41216bae68544a5b7e", [
      [ "POOL_NO_DEPTH", "group___render_system.html#gga9854c57374adef41216bae68544a5b7ea569228ed0fdd8d428a5117026b6d010e", null ],
      [ "POOL_MANUAL_USAGE", "group___render_system.html#gga9854c57374adef41216bae68544a5b7ea2d5409ddce167e1db415f09ee2160440", null ],
      [ "POOL_DEFAULT", "group___render_system.html#gga9854c57374adef41216bae68544a5b7ea00a687046bfe7a9ebd7f34256d3fbcca", null ]
    ] ],
    [ "DepthBuffer", "group___render_system.html#ga90ab98914c730458fccb9780f850b905", null ],
    [ "~DepthBuffer", "group___render_system.html#ga23ee0fd93e778767b81bebd382bb4306", null ],
    [ "_setPoolId", "group___render_system.html#ga7af5c611687492846891914dcac303d2", null ],
    [ "getPoolId", "group___render_system.html#ga82b30e2ad5de1ac4678fda52ccbaf28f", null ],
    [ "getBitDepth", "group___render_system.html#ga0da54b20b25ac5313fc8c142e8b35168", null ],
    [ "getWidth", "group___render_system.html#gae5095fe367bf95d08dee2da03810beb2", null ],
    [ "getHeight", "group___render_system.html#gaf95e6998e74db40257cb2ca5cab4bdf4", null ],
    [ "getFSAA", "group___render_system.html#ga37ddc9b5fc1fd8c5cf50e1b865d2b2fb", null ],
    [ "getFSAAHint", "group___render_system.html#ga9662342362034428346e0676fb9d1ac7", null ],
    [ "getFsaa", "group___render_system.html#ga242e53843f55de3983e6f070e88c19ae", null ],
    [ "getFsaaHint", "group___render_system.html#ga1b4eca5bc2774b80081a2f5aba90c58c", null ],
    [ "isManual", "group___render_system.html#ga4a3de78684016598642ad2d00e5caa86", null ],
    [ "isCompatible", "group___render_system.html#gae959f6dd77e0e8b6aa9b7c6a3d2d3f5d", null ],
    [ "_notifyRenderTargetAttached", "group___render_system.html#ga26c4ce1003ddab1ed7e3befecb0888a1", null ],
    [ "_notifyRenderTargetDetached", "group___render_system.html#ga227b541ef2ae3de53334c10397a08f99", null ]
];
